pytilities.delegation.delegationaspect — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.delegation »

# pytilities.delegation.delegationaspect

class `pytilities.delegation.delegationaspect.` `DelegationAspect`(*args, **kwargs)

  Aspect that delegates access on the aspected to a target object

  The effect of this is that: source_instance.attr actually returns target_instance.attr, same goes for set, and del accesses.

  The object could be a class, or an instance.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.delegation »